.. this page is needed for themes without the version dropdown

v0.0.13 ▼
============

- `development <https://yura52.github.io/delu/dev>`_
- `stable <https://yura52.github.io/delu>`_
- (v0.0.12 is not available, but its API is identical to v0.0.13)
- `v0.0.10 <https://yura52.github.io/delu/0.0.10>`_

.. note::

    Prior to v0.0.10, the library was called Zero

- `v0.0.8 <https://yura52.github.io/delu/0.0.8>`_
- `v0.0.7 <https://yura52.github.io/delu/0.0.7>`_
- `v0.0.6 <https://yura52.github.io/delu/0.0.6>`_
- `v0.0.5 <https://yura52.github.io/delu/0.0.5>`_
- `v0.0.4 <https://yura52.github.io/delu/0.0.4>`_
- `v0.0.3 <https://yura52.github.io/delu/0.0.3>`_
- `v0.0.3.dev7 <https://yura52.github.io/delu/0.0.3.dev7>`_
